@@ -1,14 +1,14 @@
 package XML::Feed::Format::Atom;
 use strict;
 use warnings;
+use v5.10;
 
-our $VERSION = '0.53';
+our $VERSION = '0.56';
 
 use base qw( XML::Feed );
 use XML::Atom::Feed;
-use XML::Atom::Util qw( iso2dt );
+use XML::Feed::Util qw( format_w3cdtf parse_datetime );
 use List::Util qw( first );
-use DateTime::Format::W3CDTF;
 use HTML::Entities;
 
 use XML::Atom::Entry;
@@ -27,7 +27,7 @@ sub identify {
 
 sub init_empty {
     my ($feed, %args) = @_;
-    $args{'Version'} ||= '1.0';
+    $args{'Version'} //= '1.0';
 
     $feed->{atom} = XML::Atom::Feed->new(%args);
     $feed;
@@ -119,11 +119,9 @@ sub image {
 sub modified {
     my $feed = shift;
     if (@_) {
-        $feed->{atom}->modified(DateTime::Format::W3CDTF->format_datetime($_[0]));
+        $feed->{atom}->modified(format_w3cdtf($_[0]));
     } else {
-        return iso2dt($feed->{atom}->modified) if $feed->{atom}->modified;
-        return iso2dt($feed->{atom}->updated)  if $feed->{atom}->updated;
-        return undef;
+        parse_datetime($feed->{atom}->modified || $feed->{atom}->updated);
     }
 }
 
