@@ -1,19 +1,19 @@
 package XML::Feed::Format::RSS;
 use strict;
 use warnings;
+use v5.10;
 
-our $VERSION = '0.53';
+our $VERSION = '0.56';
 
 use base qw( XML::Feed );
 use DateTime::Format::Mail;
 use DateTime::Format::W3CDTF;
-use XML::Atom::Util qw(iso2dt);
 use XML::Feed::Enclosure;
 use XML::Feed::Entry::Format::RSS;
+use XML::Feed::Util qw( parse_mail_date parse_w3cdtf_date );
 
 our $PREFERRED_PARSER = "XML::RSS";
 
-
 sub identify {
     my $class   = shift;
     my $xml     = shift;
@@ -23,7 +23,7 @@ sub identify {
 
 sub init_empty {
     my ($feed, %args) = @_;
-    $args{'version'} ||= '2.0';
+    $args{'version'} //= '2.0';
     eval "use $PREFERRED_PARSER"; die $@ if $@;
     $feed->{rss} = $PREFERRED_PARSER->new(%args);
     $feed->{rss}->add_module(prefix => "content", uri => 'http://purl.org/rss/1.0/modules/content/');
@@ -82,7 +82,7 @@ sub language {
         $feed->{rss}->channel('language', $_[0]);
         $feed->{rss}->channel->{dc}{language} = $_[0];
     } else {
-        $feed->{rss}->channel('language') ||
+        $feed->{rss}->channel('language') //
         $feed->{rss}->channel->{dc}{language};
     }
 }
@@ -120,7 +120,7 @@ sub generator {
         $feed->{rss}->channel->{'http://webns.net/mvcb/'}{generatorAgent} =
             $_[0];
     } else {
-        $feed->{rss}->channel('generator') ||
+        $feed->{rss}->channel('generator') //
         $feed->{rss}->channel->{'http://webns.net/mvcb/'}{generatorAgent};
     }
 }
@@ -131,7 +131,7 @@ sub author {
         $feed->{rss}->channel('webMaster', $_[0]);
         $feed->{rss}->channel->{dc}{creator} = $_[0];
     } else {
-        $feed->{rss}->channel('webMaster') ||
+        $feed->{rss}->channel('webMaster') //
         $feed->{rss}->channel->{dc}{creator};
     }
 }
@@ -147,19 +147,8 @@ sub modified {
         #$rss->channel->{dc}{date} =
         #    DateTime::Format::W3CDTF->format_datetime($_[0]);
     } else {
-        my $date;
-        eval {
-            if (my $ts = $rss->channel('pubDate')) {
-                $ts =~ s/^\s+//;
-                $ts =~ s/\s+$//;
-                $date = DateTime::Format::Mail->parse_datetime($ts);
-            } elsif ($ts = $rss->channel->{dc}{date}) {
-                $ts =~ s/^\s+//;
-                $ts =~ s/\s+$//;
-                $date = DateTime::Format::W3CDTF->parse_datetime($ts);
-            }
-        };
-        return $date;
+        return parse_mail_date($rss->channel('pubDate'))
+            || parse_w3cdtf_date($rss->channel->{dc}{date});
     }
 }
 
